"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Debug = require("debug");
const redis_store_1 = require("../storage/redis.store");
const logger = Debug('acp:service:cache');
class Cache {
    static isConnected() {
        return redis_store_1.Redis.connected;
    }
    static put(key, value, exptime) {
        logger('Caching ->', key);
        return new Promise((resolve) => {
            redis_store_1.Redis.set(key, JSON.stringify(value), () => {
                if (exptime)
                    redis_store_1.Redis.expire(key, exptime);
                logger('Cached ->', key);
                return resolve(value);
            });
        });
    }
    static get(key) {
        return new Promise((resolve, reject) => {
            redis_store_1.Redis.get(key, (error, buffer) => {
                if (error || !buffer) {
                    logger('failed cache ->', key);
                    return reject(new Error(`Cache not found for key ${key}`));
                }
                logger('From cache ->', key);
                return resolve(JSON.parse(buffer.toString()));
            });
        });
    }
    static purge(key) {
        logger('Invalidating cache ->', key);
        return new Promise((resolve) => {
            redis_store_1.Redis.del(key, (_, reply) => {
                resolve(reply);
            });
        });
    }
}
exports.Cache = Cache;
